@@ -63,8 +63,11 @@ if(isset($_GET['action'])) {
 		$remain_time=$_POST['remain_time'];
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
 		if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
+		else $no_ring_remain=0;
 		if($_POST[no_answer_limit] == "" || $_POST[no_answer_limit] < -1) $_POST[no_answer_limit]=-1;
+		else $no_answer_remain=0;
 		if($_POST[short_call_limit] == "" || $_POST[short_call_limit] < -1) $_POST[short_call_limit]=-1;
+		else $short_call_remain=0;
 		if($_POST[count_limit] == "" || $_POST[count_limit] < -1) $_POST[count_limit]=-1;
 		if($_POST[no_connected_limit] == "" || $_POST[no_connected_limit] < -1) $_POST[no_connected_limit]=-1;
 		if($_POST['month_limit_time'] == "" || $_POST['month_limit_time'] < -1) $_POST['month_limit_time']=-1;
@@ -88,14 +91,14 @@ if(isset($_GET['action'])) {
 		else{
 			$db->query("insert into sim_bank (name,tag,password,`type`) values ('$name','$tag','$password', '$banktype')");
 			//$id_t=$db->fetch_array($db->query("SELECT LAST_INSERT_ID()"));
-			$sql="insert into sim (sim_name,sim_team_id,bank_name,imei_mode,imei,remain_time,time_unit,time_limit,no_ring_limit,no_answer_limit,short_call_limit,short_time, no_ring_disable, no_answer_disable, short_call_disable,count_limit,no_connected_limit,month_limit_time,month_remain_time,month_reset_day) values";
+			$sql="insert into sim (sim_name,sim_team_id,bank_name,imei_mode,imei,remain_time,time_unit,time_limit,no_ring_limit,no_answer_limit,short_call_limit,short_time, no_ring_disable, no_answer_disable, short_call_disable,count_limit,count_remain,no_connected_limit,no_connected_remain,month_limit_time,month_remain_time,month_reset_day, month_last_reset_time) values";
 			if($banktype=='SMB128') {
 				for($i=1;$i<=128;$i++){
 					if($_POST[imei_prefix])
 						$imei=sprintf("%.11s", sprintf("%.11s",$_POST[imei_prefix])."000000000000").sprintf("%03d", $i)."0";
 					else 
 						$imei="000000000000000";
-					$sql.="('$name".sprintf("%03d",$i)."','$team_id', '$name', '$_POST[imei_mode]','$imei', '$remain_time', '$time_unit','$remain_time','$_POST[no_ring_limit]','$_POST[no_answer_limit]','$_POST[short_call_limit]','$_POST[short_time]', '$_POST[no_ring_disable]','$_POST[no_answer_disable]','$_POST[short_call_disable]','$_POST[count_limit]','$_POST[no_connected_limit]','$_POST[month_limit_time]','$_POST[month_limit_time]','$_POST[month_reset_day]')";
+					$sql.="('$name".sprintf("%03d",$i)."','$team_id', '$name', '$_POST[imei_mode]','$imei', '$remain_time', '$time_unit','$remain_time','$_POST[no_ring_limit]','$_POST[no_answer_limit]','$_POST[short_call_limit]','$_POST[short_time]', '$_POST[no_ring_disable]','$_POST[no_answer_disable]','$_POST[short_call_disable]','$_POST[count_limit]','$_POST[count_limit]','$_POST[no_connected_limit]','$_POST[no_connected_limit]','$_POST[month_limit_time]','$_POST[month_limit_time]','$_POST[month_reset_day]', now())";
 					if($i<128) $sql .= ",";
 				}
 			}
@@ -107,11 +110,12 @@ if(isset($_GET['action'])) {
 						$imei=sprintf("%.12s", sprintf("%.12s",$_POST[imei_prefix])."000000000000").sprintf("%02d", $i)."0";
 					else 
 						$imei="000000000000000";
-					$sql.="('$name".sprintf("%02d",$i)."','$team_id', '$name', '$_POST[imei_mode]','$imei', '$remain_time', '$time_unit','$remain_time','$_POST[no_ring_limit]','$_POST[no_answer_limit]','$_POST[short_call_limit]','$_POST[short_time]', '$_POST[no_ring_disable]','$_POST[no_answer_disable]','$_POST[short_call_disable]','$_POST[count_limit]','$_POST[no_connected_limit]','$_POST[month_limit_time]','$_POST[month_limit_time]','$_POST[month_reset_day]')";
+					$sql.="('$name".sprintf("%02d",$i)."','$team_id', '$name', '$_POST[imei_mode]','$imei', '$remain_time', '$time_unit','$remain_time','$_POST[no_ring_limit]','$_POST[no_answer_limit]','$_POST[short_call_limit]','$_POST[short_time]', '$_POST[no_ring_disable]','$_POST[no_answer_disable]','$_POST[short_call_disable]','$_POST[count_limit]','$_POST[count_limit]','$_POST[no_connected_limit]','$_POST[no_connected_limit]','$_POST[month_limit_time]','$_POST[month_limit_time]','$_POST[month_reset_day]', now())";
 					if($i<$j) $sql .= ",";
 				}
 			}
 			//echo $sql;
+			//exit;
 			$db->query($sql);
 			$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_bank.name='$name'");
 			while($row=$db->fetch_array($query)){
