@@ -121,9 +121,9 @@ cp -r smb_scheduler /usr/local/
 chmod -R 777 /usr/local/smb_scheduler
 [ ! -L /var/www/smb_scheduler ] && ln -s /usr/local/smb_scheduler /var/www/smb_scheduler
 
-[ -f "/etc/conf.d/local.start" ] && local="/etc/conf.d/local.start";
-[ -f "/etc/rc.d/rc.local" ] && local="/etc/rc.d/rc.local"
-[ -f "/etc/rc.local" ] && local="/etc/rc.local"
+[ -f "/etc/conf.d/local.start" ] && local="/etc/conf.d/local.start" && chmod +x /etc/conf.d/local.start
+[ -f "/etc/rc.d/rc.local" ] && local="/etc/rc.d/rc.local" && chmod +x /etc/rc.d/rc.local
+[ -f "/etc/rc.local" ] && local="/etc/rc.local" && chmod +x /etc/rc.local
 
 
 rclocaltmp=`mktemp /tmp/rclocal.XXXXXXXXXX`
@@ -137,7 +137,7 @@ fi
 
 if grep -q "^exit 0$" $local
 then
-    sed -i '/exit\ 0/i\/usr\/local\/smb_scheduler\/run_scheduler' /etc/rc.local
+    sed -i '/exit\ 0/i\/usr\/local\/smb_scheduler\/run_scheduler' $local
 else
     echo "/usr/local/smb_scheduler/run_scheduler" >> $local
 fi
